<?php

/**
* @file
* Views field handler. Contains all relevant VBO options and related logic.
* Implements the Views Form API.
*/

class search_api_vbo_handler_field_search_api_vbo extends views_bulk_operations_handler_field_operations {
	
	var $search_api_item_id_field = 'search_api_item_id';

  function init(&$view, &$options) {
    parent::init($view, $options);
    
    // Set real_field attribute to be the search_api_index_result_id_field specified in the handler definition
    if (isset($this->definition['search_api_item_id_field'])) {
    	$this->search_api_item_id_field = $this->definition['search_api_item_id_field'];    	
    } 
  }

  /**
   * Determine the base table of the VBO field, and then use it to determine
   * the entity type that VBO is operating on.
   */
  function get_entity_type() {
  	$entity_type = parent::get_entity_type();
  	if  ($entity_type !== FALSE) {
  		return $entity_type;
  	}
  	
  	// Use 'search_api_index' as base table
    $base_table = 'search_api_index';

    // If the current field is under a relationship you can't be sure that the
    // base table of the view is the base table of the current field.
    // For example a field from a node author on a node view does have users as base table.
    if (!empty($this->options['relationship']) && $this->options['relationship'] != 'none') {
      $relationships = $this->view->display_handler->get_option('relationships');
      $options = $relationships[$this->options['relationship']];
      $data = views_fetch_data($options['table']);
      $base_table = $data[$options['field']]['relationship']['base'];
    }
    // The base table is now known, use it to determine the entity type.
    foreach (entity_get_info() as $entity_type => $info) {
      if (isset($info['base table']) && $info['base table'] == $base_table) {
        return $entity_type;
      }
      elseif (isset($info['revision table']) && $info['revision table'] == $base_table) {
        $this->revision = TRUE;
        return $entity_type;
      }
    }
    // This should never happen.
    _views_bulk_operations_report_error("[search_api_vbo_handler_field_search_api_vbo] Could not determine the entity type for VBO field on views base table %table", array('%table' => $base_table));
    return FALSE;  		
  }

  /**
   * Get the value that's supposed to be rendered.
   *
   * @param $values
   *   An object containing all retrieved values.
   * @param $field
   *   Optional name of the field where the value is stored.
   */
  function get_value($values, $field = NULL) {  	
    if (isset($values->{$this->search_api_item_id_field})) {
      return $values->{$this->search_api_item_id_field};
    }
  }
  
}
